#' @title Cauchy Distribution
#' @description Family objects for cauchy distribution provide a convenient way to specify the details of the models used by functions such as \code{elliptical}.
#' @return An object of class "family" for cauchy distribution.
#' @references Fang, K. T., Kotz, S. and NG, K. W. (1990, ISBN:9781315897943).
#' Symmetric Multivariate and Related Distributions. London: Chapman and Hall.
#' @seealso \code{\link{family.elliptical}}, \code{\link{elliptical}}, \code{\link{gwer}}
#' @keywords elliptical distributions
#' @examples
#' data(luzdat)
#' y <- luzdat$y
#' x1 <- luzdat$x1 ; x1 <- factor(x1) ; x1 <- C(x1,treatment)
#' x2 <- luzdat$x2
#' x3 <- (luzdat$x2)^2
#' luz <- data.frame(y,x1,x2,x3)
#' elliptical.fitC <- elliptical(y ~ x1+x2+x3, family = Cauchy()
#' ,data=luz)
#' family(elliptical.fitC)
#' @export


Cauchy <- function () 
{
  make.family.elliptical("Cauchy")
}
